@@ -1,24 +1,27 @@
+package Test::Mocha;
+# ABSTRACT: Test double framework with method stubs and behaviour verification
+$Test::Mocha::VERSION = '0.62_01';  # TRIAL
+
 use strict;
 use warnings;
 
-package Test::Mocha;
-# ABSTRACT: Test Spy/Stub Framework
-$Test::Mocha::VERSION = '0.60_01';  # TRIAL
-
-use Carp qw( croak );
-use Exporter qw( import );
-use Scalar::Util qw( blessed );
+use Carp 'croak';
+use Exporter 'import';
+use Scalar::Util 'blessed';
 use Test::Mocha::CalledOk::Times;
 use Test::Mocha::CalledOk::AtLeast;
 use Test::Mocha::CalledOk::AtMost;
 use Test::Mocha::CalledOk::Between;
 use Test::Mocha::Mock;
-use Test::Mocha::Types 'NumRange', Mock => { -as => 'MockType' };
-use Test::Mocha::Util qw( getattr get_method_call is_called );
+use Test::Mocha::Spy;
+use Test::Mocha::Types 'NumRange';
+use Test::Mocha::Util 'extract_method_name';
 use Types::Standard qw( ArrayRef HashRef Num slurpy );
 
 our @EXPORT = qw(
   mock
+  spy
+  class_mock
   stub
   returns
   throws
@@ -40,34 +43,39 @@ our @EXPORT = qw(
 $Carp::Internal{$_}++ foreach qw(
   Test::Mocha
   Test::Mocha::CalledOk
-  Test::Mocha::Inspect
-  Test::Mocha::Mock
-  Test::Mocha::Util
   Test::Mocha::MethodStub
-  Test::Mocha::Verify
+  Test::Mocha::Mock
+  Test::Mocha::Spy
+  Test::Mocha::Util
 );
 
 sub mock {
-    return Test::Mocha::Mock->new(@_);
+    return Test::Mocha::Mock->__new(@_);
+}
+
+sub spy ($) {
+    return Test::Mocha::Spy->__new(@_);
 }
 
 sub stub (&@) {
-    my ( $arg, @executions ) = @_;
+    my ( $coderef, @responses ) = @_;
 
-    foreach (@executions) {
+    foreach (@responses) {
         croak 'stub() responses should be supplied using ',
           'returns(), throws() or executes()'
           if ref ne 'CODE';
     }
 
-    $Test::Mocha::Mock::num_method_calls = 0;
-    my $method_call = get_method_call($arg);
-    my $stubs = getattr( $method_call->invocant, 'stubs' );
-    unshift @{ $stubs->{ $method_call->name } }, $method_call;
+    # add stub to mock
+    my $method_call =
+      Test::Mocha::Mock->__capture_method_call( $coderef, 'stub' );
+    unshift @{ $method_call->invocant->__stubs->{ $method_call->name } },
+      $method_call;
 
+    # add response to stub
     Test::Mocha::MethodStub->cast($method_call);
-    push @{ getattr( $method_call, 'executions' ) }, @executions;
-    return $method_call;  # for backwards compatibility
+    push @{ $method_call->__responses }, @responses;
+    return;
 }
 
 sub returns (@) {
@@ -76,7 +84,7 @@ sub returns (@) {
       if @return_values == 1;
     return sub { @return_values }
       if @return_values > 1;
-    return sub { };       # if @return_values == 0
+    return sub { };  # if @return_values == 0
 }
 
 sub throws (@) {
@@ -98,63 +106,19 @@ sub executes (&) {
 ## no critic (RequireArgUnpacking,ProhibitMagicNumbers)
 sub called_ok (&;@) {
     my $coderef = shift;
+
     my $called_ok;
-    my $class;
-    my $value;
     my $test_name;
-
-    # unpack the args - different possibilities due to backwards compatibility
-    if ( @_ == 1 ) {
-        if ( ref $_[0] eq 'CODE' ) {
-            $called_ok = $_[0];
-        }
-        else {
-            $test_name = $_[0];
-        }
+    if ( @_ > 0 && ref $_[0] eq 'CODE' ) {
+        $called_ok = shift;
     }
-    elsif ( @_ == 2 ) {
-        if ( ref $_[0] eq 'CODE' ) {
-            ( $called_ok, $test_name ) = @_;
-        }
-        else {
-            ( $class, $value ) = @_;
-        }
-    }
-    elsif ( @_ == 3 ) {
-        ( $class, $value, $test_name ) = @_;
+    if ( @_ > 0 ) {
+        $test_name = shift;
     }
 
-    $Test::Mocha::Mock::num_method_calls = 0;
-    my $method_call = get_method_call($coderef);
+    my $method_call =
+      Test::Mocha::Mock->__capture_method_call( $coderef, 'verify' );
 
-    # v0.50 behaviour
-    if ( defined $class ) {
-        my %options = (
-            times    => 'Test::Mocha::CalledOk::Times',
-            atleast  => 'Test::Mocha::CalledOk::AtLeast',
-            atmost   => 'Test::Mocha::CalledOk::AtMost',
-            at_least => 'Test::Mocha::CalledOk::AtLeast',
-            at_most  => 'Test::Mocha::CalledOk::AtMost',
-            between  => 'Test::Mocha::CalledOk::Between',
-        );
-        croak "called_ok() was given an invalid option: '$class'"
-          unless defined $options{$class};
-
-        if ( $class ne 'between' ) {
-            croak "'$class' option must be a number"
-              unless Num->check($value);
-        }
-        else {
-            croak "'$class' option must be an arrayref "
-              . 'with 2 numbers in ascending order'
-              unless NumRange->check($value);
-        }
-
-        $options{$class}->test( $method_call, $value, $test_name );
-        return;
-    }
-
-    # current behaviour
     ## no critic (ProhibitAmpersandSigils)
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     $called_ok ||= &times(1);  # default if no times() is specified
@@ -210,78 +174,21 @@ sub between ($$) {
     };
 }
 
-# verify() has been retained for backwards compatibility only
-
-sub verify ($;@) {
-    # uncoverable pod
-    my ( $mock, %options ) = _get_called_ok_args(@_);
-
-    warnings::warnif( 'deprecated',
-        'verify() is deprecated; use called_ok() instead' );
-    croak 'verify() must be given a mock object'
-      if !MockType->check($mock);
-
-    require Test::Mocha::Verify;
-    return Test::Mocha::Verify->new( mock => $mock, %options );
-}
-
-## no critic (RequireArgUnpacking)
-sub _get_called_ok_args {
-    my $coderef = shift;
-    my $test_name;
-    $test_name = pop if ( @_ % 2 == 1 );
-    my %options = @_;
-
-    # set default option if none given
-    $options{times} = 1 if keys %options == 0;
-
-    croak 'You can set only one of these options: ' . join ', ',
-      map { "'$_'" } keys %options
-      unless keys %options == 1;
-
-    ## no critic (ProhibitCascadingIfElse)
-    if ( defined $options{times} ) {
-        croak "'times' option must be a number"
-          unless Num->check( $options{times} );
-    }
-    elsif ( defined $options{at_least} ) {
-        croak "'at_least' option must be a number"
-          unless Num->check( $options{at_least} );
-    }
-    elsif ( defined $options{at_most} ) {
-        croak "'at_most' option must be a number"
-          unless Num->check( $options{at_most} );
-    }
-    elsif ( defined $options{between} ) {
-        croak "'between' option must be an arrayref "
-          . 'with 2 numbers in ascending order'
-          unless NumRange->check( $options{between} );
-    }
-    else {
-        my ($option) = keys %options;
-        croak "called_ok() was given an invalid option: '$option'";
-    }
-    $options{test_name} = $test_name if defined $test_name;
-
-    return ( $coderef, %options );
-}
-## use critic
-
 sub inspect (&) {
-    my ($arg) = @_;
+    my ($coderef) = @_;
+    my $method_call =
+      Test::Mocha::Mock->__capture_method_call( $coderef, 'inspect' );
 
-    $Test::Mocha::Mock::num_method_calls = 0;
-    my $method_call = get_method_call($arg);
-    my $mock        = $method_call->invocant;
-    my $calls       = getattr( $mock, 'calls' );
-    return grep { $method_call->satisfied_by($_) } @{$calls};
+    return
+      grep { $method_call->__satisfied_by($_) }
+      @{ $method_call->invocant->__calls };
 }
 
 sub inspect_all ($) {
     my ($mock) = @_;
 
-    croak 'inspect_all() must be given a mock object'
-      if !MockType->check($mock);
+    croak 'inspect_all() must be given a mock or spy object'
+      if !$mock->isa('Test::Mocha::SpyBase');
 
     return @{ $mock->{calls} };
 }
@@ -289,12 +196,12 @@ sub inspect_all ($) {
 sub clear (@) {
     my @mocks = @_;
 
-    ## no critic (ProhibitBooleanGrep)
-    croak 'clear() must be given one or more mock objects'
-      if !@mocks || grep { !MockType->check($_) } @mocks;
-    ## use critic
+    croak 'clear() must be given mock or spy objects'
+      if @mocks == 0;
+    croak 'clear() accepts mock and spy objects only'
+      if 0 < ( grep { !ref $_ || !$_->isa('Test::Mocha::SpyBase') } @mocks );
 
-    @{ getattr( $_, 'calls' ) } = () foreach @mocks;
+    @{ $_->__calls } = () foreach @mocks;
 
     return;
 }
@@ -311,6 +218,30 @@ sub SlurpyHash () {
 }
 ## use critic
 
+sub class_mock {
+    my ($mocked_class) = @_;
+
+    my $module_file = join( q{/}, split q{::}, $mocked_class ) . '.pm';
+    my $caller_pkg = caller;
+    no strict 'refs';  ## no critic (TestingAndDebugging::ProhibitNoStrict)
+
+    # make sure the real module is not already loaded
+    croak "Package '$mocked_class' is already loaded so it cannot be mocked"
+      if defined ${ $caller_pkg . '::INC' }{$module_file};
+
+    # check if package has already been mocked
+    croak "Package '$mocked_class' is already mocked"
+      if defined *{ $mocked_class . '::AUTOLOAD' }{CODE};
+
+    my $mock = mock($mocked_class);
+
+    *{ $mocked_class . '::AUTOLOAD' } = sub {
+        my ($method) = extract_method_name( our $AUTOLOAD );
+        $mock->$method(@_);
+    };
+    return $mock;
+}
+
 1;
 
 __END__
@@ -319,16 +250,20 @@ __END__
 
 =head1 NAME
 
-Test::Mocha - Test Spy/Stub Framework
+Test::Mocha - Test double framework with method stubs and behaviour verification
+
+=for html
+<a href="https://travis-ci.org/stevenl/Test-Mocha"><img src="https://travis-ci.org/stevenl/Test-Mocha.svg?branch=master" alt="Build Status"></a>
+<a href='https://coveralls.io/r/stevenl/Test-Mocha?branch=master'><img src='https://coveralls.io/repos/stevenl/Test-Mocha/badge.png?branch=master' alt='Coverage Status' /></a>
 
 =head1 VERSION
 
-version 0.60_01
+version 0.62_01
 
 =head1 SYNOPSIS
 
-Test::Mocha is a test spy framework for testing code that has dependencies on
-other objects.
+Test::Mocha is a test double framework for testing code that has dependencies
+on other objects.
 
     use Test::More tests => 2;
     use Test::Mocha;
@@ -353,20 +288,13 @@ other objects.
 
 =head1 DESCRIPTION
 
-B<The API may still be subject to change. I will try to keep it backwards
-compatible as much as possible.>
-
-We find all sorts of excuses to avoid writing tests for our code. Often it
-seems too hard to isolate the code we want to test from the objects it is
-dependent on. I'm too lazy and impatient to code my own mocks. Mocking
-frameworks can help with this but they still take too long to set up the mock
-objects. Enough setting up! I just want to get on with the actual testing.
-
-Test::Mocha offers a simpler and more intuitive approach. Rather than setting
-up the expected interactions beforehand, you ask questions about interactions
-after the execution. The mocks can be created in almost no time. Yet they're
-ready to be used out-of-the-box by pretending to be any type you want them to
-be and accepting any method call on them.
+Test::Mocha is a test double framework inspired by Java's Mockito.
+It offers a different approach to other mocking frameworks in that instead
+of setting up the expected behaviour beforehand you ask questions about
+interactions after execution of the system-under-test. This approach means
+there is less setup needed to use your test double which means you can
+focus more on testing, and it minimises the coupling of the tests to the
+implementation which means less maintenance of your test code.
 
 Explicit stubbing is only required when the dependent object is expected to
 return a specific response. And you can even use argument matchers to skip
@@ -381,39 +309,59 @@ interfaces rather than on internal state.
 
 =head2 mock
 
-    my $mock = mock;
+    $mock = mock;
 
 C<mock()> creates a new mock object. It's that quick and simple!
+It is ready out-of-the-box to pretend to be any object you want it to be
+and to accept any method calls on it.
 
-The mock object is ready, as-is, to pretend to be anything you want it to be.
-Calling C<isa()> or C<does()> on the object will always return true. This
-is particularly handy when dependent objects are required to satisfy type
-constraint checks with OO frameworks such as L<Moose>.
+Any public method may be called on mocks. By default the methods will return
+C<undef> or C<()> depending on the context. See L</"stub"> below for how to
+change this behaviour.
 
-    ok( $mock->isa('AnyClass') );
-    ok( $mock->does('AnyRole') );
-    ok( $mock->DOES('AnyRole') );
+    $result = $mock->method(@args); # returns undef
+    @result = $mock->method(@args); # returns ()
 
-It will also accept any method call on it. By default, method calls will
-return C<undef> (in scalar context) or an empty list (in list context).
+C<isa()>, C<does()> or C<DOES()> returns true for any class or role name.
+C<can()> returns a reference to the default public method. This is
+particularly handy when the dependent object needs to satisfy attribute
+type constraint checks with OO frameworks such as L<Moose>.
 
-    ok( $mock->can('any_method') );
-    is( $mock->any_method(@args), undef );
+    $mock->isa('AnyClass');     # returns 1
+    $mock->does('AnyRole');     # returns 1
+    $mock->DOES('AnyRole');     # returns 1
+    $mock->can('any_method');   # returns a coderef
 
-You can stub C<ref()> to specify the value it should return (see below for
-more info about stubbing).
+C<ref()> is a special method that you can stub to specify the value you would
+like returned when you use the C<ref()> function with a mock object.
 
-    stub { $mock->ref } returns 'AnyClass';
-    is( $mock->ref, 'AnyClass' );
-    is( ref($mock), 'AnyClass' );
+    stub { $mock->ref } returns 'SomeClass';
+    print ref($mock); # prints 'SomeClass'
+
+=head2 spy
+
+    $spy = spy($object);
+
+Don't want to abstract away the behaviour of an entire class? Use a spy.
+Spies act as wrappers to real objects. Rather than giving pretend responses
+as mocks do, they delegate the method calls to the real objects (including
+the UNIVERSAL methods like C<isa()> and C<DOES>) and return their actual
+responses. But the method calls can also be verified using L</"called_ok">
+or overridden using L</"stub">.
+
+This means you can use the existing behaviour of the object and fake only
+parts of it, such as a call to a server that's not available in your dev
+environment or that returns non-deterministic results.
 
 =head2 stub
 
-    stub { $mock->method(@args) } returns(@values) | throws($exception) | executes($coderef)
+    stub { $mock->method(@args) } returns(@values)
+    stub { $mock->method(@args) } throws($exception)
+    stub { $mock->method(@args) } executes($coderef)
 
 By default, the mock object already acts as a stub that accepts any method
-call and returns C<undef>. However, you can use C<stub()> to tell a method to
-give an alternative response. You can specify 3 types of responses:
+call and returns C<undef> or C<()>. However, you can use C<stub()> to tell a
+method to give an alternative response. You can specify 3 types of responses:
 
 =over 4
 
@@ -421,15 +369,15 @@ give an alternative response. You can specify 3 types of responses:
 
 Specifies that a stub should return 1 or more values.
 
-    stub { $mock->method(@args) } ) returns 1, 2, 3;
-    is_deeply( [ $mock->method(@args) ], [ 1, 2, 3 ] );
+    stub { $mock->method(@args) } returns 1, 2, 3;
+    print $mock->method(@args);  # prints "123"
 
 =item C<throws($message)>
 
 Specifies that a stub should raise an exception.
 
     stub { $mock->method(@args) } throws 'an error';
-    ok( exception { $mock->method(@args) } );
+    $mock->method(@args);  # croaks with "an error at test.t line 10."
 
 =item C<executes($coderef)>
 
@@ -444,44 +392,49 @@ in the method call are passed on to the callback.
         return $returns[$i];
     };
 
-    is( $list->get(0), 'first'  );
-    is( $list->get(1), 'second' );
-    is( $list->get(5), undef    );
-    like( exception { $list->get(-1) }, qr/^index out of bounds/ ),
+    print $list->get(0);   # prints "first"
+    print $list->get(1);   # prints "second"
+    print $list->get(5);   # warns "Use of uninitialized value in print at test.t line 16."
+    print $list->get(-1);  # dies with "Index out of bounds at test.t line 10."
 
 =back
 
-A stub applies to the exact method and arguments specified (but see also
+A stub applies to the exact mock, method and arguments specified (but see also
 L</"ARGUMENT MATCHING"> for a shortcut around this).
 
     stub { $list->get(0) } returns 'first';
     stub { $list->get(1) } returns 'second';
 
-    is( $list->get(0), 'first'  );
-    is( $list->get(1), 'second' );
-    is( $list->get(2),  undef   );
+    print $list->get(0);  # prints "first"
+    print $list->get(1);  # prints "second"
+    print $list->get(2);  # nothing printed (since default stub returns an empty list)
 
 Chain responses together to provide a consecutive series.
 
     stub { $iterator->next }
       returns(1), returns(2), returns(3), throws('exhausted');
 
-    ok( $iterator->next == 1 );
-    ok( $iterator->next == 2 );
-    ok( $iterator->next == 3 );
-    ok( exception { $iterator->next } );
+    print $iterator->next;  # prints "1"
+    print $iterator->next;  # prints "2"
+    print $iterator->next;  # prints "3"
+    print $iterator->next;  # croaks with "exhausted at test.t line 13."
 
 The last stubbed response will persist until it is overridden.
 
     stub { $warehouse->has_inventory($item, 10) } returns 1;
-    ok( $warehouse->has_inventory($item, 10) ) for 1 .. 5;
+    print( $warehouse->has_inventory($item, 10) ) for 1 .. 5; # prints "11111"
 
     stub { $warehouse->has_inventory($item, 10) } returns '';
-    ok( !$warehouse->has_inventory($item, 10) ) for 1 .. 5;
+    print( $warehouse->has_inventory($item, 10) ) for 1 .. 5; # nothing printed
 
 =head2 called_ok
 
-    called_ok { $mock->method(@args) } [ times($n) | atleast($n) | atmost($n) | between($m, $n) ], [$test_name]
+    called_ok { $mock->method(@args) }
+    called_ok { $mock->method(@args) } times($n)
+    called_ok { $mock->method(@args) } atleast($n)
+    called_ok { $mock->method(@args) } atmost($n)
+    called_ok { $mock->method(@args) } between($m, $n)
+    called_ok { $mock->method(@args) } $test_name
 
 C<called_ok()> is used to test the interactions with the mock object. You can
 use it to verify that the correct method was called, with the correct set of
@@ -490,19 +443,23 @@ L<Test::Simple> and Co - it will print the test result along with your other
 tests and you must count calls to C<called_ok()> in your test plans.
 
     called_ok { $warehouse->remove($item, 50) };
-    # prints: ok 1 - remove("book", 50) was called 1 time(s)
+    # prints "ok 1 - remove("book", 50) was called 1 time(s)"
 
-An option may be specified to constrain the test.
+The following functions are available to verify the number of calls:
 
 =over 4
 
 =item C<times>
 
 Specifies the number of times the given method is expected to be called.
-The default is 1 if no other option is specified.
+C<times(1)> is the default if no option is specified.
 
     called_ok { $mock->method(@args) } times(3);
-    # prints: ok 1 - method(@args) was called 3 time(s)
+    # prints "ok 1 - method(@args) was called 3 time(s)"
+
+Note: C<times()> may clash with the built-in function with the same name.
+You may explicitly specify which one you want by qualifying it as
+C<&times(3)> or C<CORE::times>.
 
 =item C<atleast>
 
@@ -510,7 +467,7 @@ Specifies the minimum number of times the given method is expected to be
 called.
 
     called_ok { $mock->method(@args) } atleast(3);
-    # prints: ok 1 - method(@args) was called at least 3 time(s)
+    # prints "ok 1 - method(@args) was called at least 3 time(s)"
 
 =item C<atmost>
 
@@ -518,7 +475,7 @@ Specifies the maximum number of times the given method is expected to be
 called.
 
     called_ok { $mock->method(@args) } atmost(5);
-    # prints: ok 1 - method(@args) was called at most 5 time(s)
+    # prints "ok 1 - method(@args) was called at most 5 time(s)"
 
 =item C<between>
 
@@ -526,34 +483,34 @@ Specifies the minimum and maximum number of times the given method is
 expected to be called.
 
     called_ok { $mock->method(@args) } between(3, 5);
-    # prints: ok 1 - method(@args) was called between 3 and 5 time(s)
+    # prints "ok 1 - method(@args) was called between 3 and 5 time(s)"
 
 =back
 
-An optional C<$test_name> may be specified to be printed instead of the
-default.
+An optional last argument C<$test_name> may be specified to be printed instead
+of the default.
 
     called_ok { $warehouse->remove_inventory($item, 50) } 'inventory removed';
-    # prints: ok 1 - inventory removed
+    # prints "ok 1 - inventory removed"
 
     called_ok { $warehouse->remove_inventory($item, 50) } times(0), 'inventory not removed';
-    # prints: ok 2 - inventory not removed
+    # prints "ok 2 - inventory not removed"
 
 =head2 inspect
 
     @method_calls = inspect { $mock->method(@args) };
 
     ($method_call) = inspect { $warehouse->remove_inventory(Str, Int) };
+    $method_call->name;           # "remove_inventory"
+    $method_call->args;           # ("book", 50)
+    $method_call->caller;         # ("test.pl", 5)
+    $method_call->stringify;      # 'remove_inventory("book", 50)'
+    $method_call->stringify_long; # 'remove_inventory("book", 50) called at test.pl line 5'
 
-    is $method_call->name,            'remove_inventory';
-    is_deeply [$method_call->args],   ['book', 50];
-    is_deeply [$method_call->caller], ['test.pl', 5];
-    is $method_call->stringify_long,
-        'remove_inventory("book", 50) called at test.pl line 5';
-
-C<inspect()> returns a list of method calls matching the given method call
-specification. It can be useful for debugging failed C<called_ok()> calls.
-Or use it in place of a complex C<called_ok()> call to break it down into
+C<inspect()> returns a list of method call objects that match the given method
+call specification. It is used to inspect the methods that have been called on
+the mock object. It can be useful for debugging failed C<called_ok()> calls.
+Or use it in place of a complex call to C<called_ok()> to break it down in
 smaller tests.
 
 The method call objects have the following accessor methods:
@@ -572,25 +529,32 @@ C<args> - The list of arguments passed to the method call.
 
 C<caller> - The file and line number from which the method was called.
 
+=item *
+
+C<stringify> - The name and arguments as a string.
+
+=item *
+
+C<stringify_long> - The name, arguments, file and line number as a string.`
+
 =back
 
-They are also C<string> overloaded to return the name.
+They are also string overloaded with the value from C<stringify>.
 
 =head2 inspect_all
 
     @all_method_calls = inspect_all $mock
 
-C<inspect_all()> returns a list containing all methods called on the mock
-object. This is mainly used for debugging.
+C<inspect_all()> returns a list of all methods called on the mock object.
+This is mainly used for debugging.
 
 =head2 clear
 
     clear $mock1, $mock2, ...
 
 Clears the method call history for one or more mocks so that they can be
-reused in another test. Note that this does not affect the stubbed methods.
-
-=for Pod::Coverage verify
+reused in another test. Note that this does not clear the methods that have
+been stubbed.
 
 =head1 ARGUMENT MATCHING
 
@@ -657,15 +621,33 @@ they will match empty argument lists.
 
 =for Pod::Coverage SlurpyArray SlurpyHash
 
-=head1 TO DO
+=head1 MOCKING CLASS METHODS (experimental)
 
-=over 4
+=head2 class_mock
 
-=item *
+C<class_mock()> creates a mock for stubbing class methods and module functions.
 
-Module functions and class methods
+    class_mock 'Some::Class';
 
-=back
+To stub a class method or module function:
+
+    stub { Some::Class->some_class_method() } returns 'something';
+    is( Some::Class->some_class_method(), 'something' );
+
+    stub { Some::Class::some_module_function() } returns 'something';
+    is( Some::Class::some_module_function(), "something" );
+
+Validation is handled similarly.
+
+    called_ok { Some::Class->some_class_method() } "some_class_method called";
+    called_ok { Some::Class::some_module_function() } "some_module_function called";
+
+Note: The original class that you mock must not be imported before you have
+finished stubbing the class. This means that if your module under test C<use>s
+it, then you must C<use_ok> or C<require> the test module after stubbing the
+mock class.
+
+Also note: Currently you cannot stub new().
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -674,7 +656,7 @@ Module functions and class methods
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-test-mocha at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Mocha>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Test-Mocha>. You will be automatically notified of any
 progress on the request by the system.
 
 =head1 AUTHOR
@@ -689,13 +671,18 @@ Charles (CYCLES).
 It is inspired by the popular L<Mockito|http://code.google.com/p/mockito/>
 for Java and Python by Szczepan Faber.
 
+It is not associated with the Javascript test framework for node.js called
+Mocha. I named Test::Mocha before that came about.
+
+The C<class_mock()> function was contributed by Scott Davis.
+
 =head1 SEE ALSO
 
 L<Test::MockObject>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Lee.
+This software is copyright (c) 2015 by Steven Lee.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
