@@ -1,9 +1,9 @@
 package Test::Mocha::MethodCall;
 # ABSTRACT: Objects to represent method calls
-$Test::Mocha::MethodCall::VERSION = '0.60_01';  # TRIAL
+$Test::Mocha::MethodCall::VERSION = '0.62_01';  # TRIAL
+use parent 'Test::Mocha::Method';
 use strict;
 use warnings;
-use parent qw( Test::Mocha::Method );
 
 sub new {
     # uncoverable pod
