@@ -1,11 +1,10 @@
 package Test::Mocha::Types;
 # ABSTRACT: Internal type constraints
-$Test::Mocha::Types::VERSION = '0.60_01';  # TRIAL
+$Test::Mocha::Types::VERSION = '0.62_01';  # TRIAL
 use Type::Library
   -base,
   -declare => qw(
   Matcher
-  Mock
   NumRange
   Slurpy
 );
@@ -19,8 +18,6 @@ union Matcher,
     class_type( { class => 'Moose::Meta::TypeConstraint' } ),
   ];
 
-class_type Mock, { class => 'Test::Mocha::Mock' };
-
 declare NumRange, as Tuple [ Num, Num ], where { $_->[0] < $_->[1] };
 
 # this hash structure is created by Types::Standard::slurpy()
